@@ -215,6 +215,42 @@ def test_get_user_from_session_throws_rte_if_non_ok_response():
     assert "value" in str(exc_info.value)
 
 
+@responses.activate
+def test_get_user_from_active_session_for_ok_response():
+    session_id = str(uuid4())
+
+    def request_callback(request):
+        return HTTPStatus.OK, {}, json.dumps({
+            "data": session_response
+        })
+
+    responses.add_callback(
+        responses.GET,
+        f"http://dummy_authentication/api/v1/sessions/{session_id}/active",
+        callback=request_callback,
+        content_type="application/json",
+    )
+    session = user_service.get_user_from_active_session(session_id)
+    assert Session.from_dict(session_response) == session
+
+
+@responses.activate
+def test_get_user_from_active_session_throws_rte_if_non_ok_response():
+    session_id = str(uuid4())
+    responses.add(
+        responses.GET,
+        f"http://dummy_authentication/api/v1/sessions/{session_id}/active",
+        status=500,
+        json=dict(key="value"),
+    )
+    with pytest.raises(RuntimeError) as exc_info:
+        user_service.get_user_from_active_session(session_id)
+
+    assert "500" in str(exc_info.value)
+    assert "key" in str(exc_info.value)
+    assert "value" in str(exc_info.value)
+
+
 user_dict = {
     "created_at": "2018-10-18T09:05:59.334113",
     "credentials": [
@@ -309,3 +345,24 @@ def test_login_raises_too_many_requests_error_if_status_code_received_from_user_
     )
     with pytest.raises(TooManyRequests):
         user_service.login_with_mobile(phone_number="8130813081", otp="1339")
+
+
+@responses.activate
+def test_mobile_login_with_expiry():
+    expiry = 600
+
+    def request_callback(request):
+        payload = json.loads(request.body)
+        assert payload["expiry_seconds"] == expiry
+        return HTTPStatus.CREATED, {}, json.dumps({
+            "data": {**session_response, "expiry_seconds": expiry}
+        })
+
+    responses.add_callback(
+        responses.POST,
+        f"http://dummy_authentication/api/v1/sign_in",
+        callback=request_callback,
+        content_type="application/json",
+    )
+    user_service.login_with_mobile(phone_number="8130813081", otp="1339", expiry_seconds=expiry)
+
