@@ -1,5 +1,5 @@
 from http import HTTPStatus
-from typing import List
+from typing import List, Optional
 from uuid import UUID
 
 import requests
@@ -45,20 +45,31 @@ class UserService:
         )
 
     def login_with_mobile(
-        self, phone_number: str, otp: str, region: CountryCode = CountryCode.INDIA
+        self,
+        phone_number: str,
+        otp: str,
+        region: CountryCode = CountryCode.INDIA,
+        expiry_seconds: Optional[int] = None,
     ) -> Session:
         return self._login(
             cred_type=CredentialType.MOBILE,
             identity=phone_number,
             otp=otp,
             region=region,
+            expiry_seconds=expiry_seconds,
         )
 
     def login_with_oauth(self, id_token: str) -> Session:
         return self._login(cred_type=CredentialType.OAUTH, identity=id_token)
 
     def _login(
-        self, cred_type, identity, password=None, otp=None, region=CountryCode.INDIA
+        self,
+        cred_type,
+        identity,
+        password=None,
+        otp=None,
+        region=CountryCode.INDIA,
+        expiry_seconds: Optional[int] = None,
     ) -> Session:
         body = {
             "identity": identity,
@@ -69,6 +80,9 @@ class UserService:
             body["password"] = password
         elif cred_type == CredentialType.MOBILE:
             body["otp"] = otp
+            if expiry_seconds:
+                body["expiry_seconds"] = expiry_seconds
+
         request_url = f"{self._authentication_url}/api/v1/sign_in"
         response = requests.post(request_url, json=body)
         log(
@@ -100,6 +114,17 @@ class UserService:
 
         self._raise_response_error(response)
 
+    def get_user_from_active_session(self, session_id: str) -> Session:
+        response = requests.get(
+            f"{self._authentication_url}/api/v1/sessions/{session_id}/active"
+        )
+        if response.status_code == HTTPStatus.OK:
+            return Session.from_dict(response.json()["data"])
+        if response.status_code == HTTPStatus.NOT_FOUND:
+            raise NoSuchUser
+
+        self._raise_response_error(response)
+
     def attach_device(self, user_device: UserDevice):
         request_url = f"{self._profile_url}/api/v1/devices"
         request_json = user_device.to_dict()
